# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"before_send": "00_core.ipynb",
         "capture_error": "00_core.ipynb",
         "logger": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://jeremytee97.github.io/lambda-logger/"

git_url = "https://github.com/jeremytee97/lambda-logger/tree/master/"

def custom_doc_links(name): return None
